pub struct Location {
pub latitude: f64,
pub longitude: f64,
pub elevation: f64,
}Expand description
Specifies the geographic coordinates and elevation of a location.
Fields
latitude: f64The latitude coordinate in degrees. Should be a number between -90 and 90.
longitude: f64The longitude coordinate in degrees. Should be a number between -180 and 180.
elevation: f64The elevation of the location in meters with respect to surrounding terrain. Should be a positive number.